# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['AttributeImporterIdentityProviderMapperArgs', 'AttributeImporterIdentityProviderMapper']

@pulumi.input_type
class AttributeImporterIdentityProviderMapperArgs:
    def __init__(__self__, *,
                 identity_provider_alias: pulumi.Input[str],
                 realm: pulumi.Input[str],
                 user_attribute: pulumi.Input[str],
                 attribute_friendly_name: Optional[pulumi.Input[str]] = None,
                 attribute_name: Optional[pulumi.Input[str]] = None,
                 claim_name: Optional[pulumi.Input[str]] = None,
                 extra_config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AttributeImporterIdentityProviderMapper resource.
        :param pulumi.Input[str] identity_provider_alias: The alias of the associated identity provider.
        :param pulumi.Input[str] realm: The name of the realm.
        :param pulumi.Input[str] user_attribute: The user attribute or property name to store the mapped result.
        :param pulumi.Input[str] attribute_friendly_name: For SAML based providers, this is the friendly name of the attribute to search for in the assertion. Conflicts with `attribute_name`.
        :param pulumi.Input[str] attribute_name: For SAML based providers, this is the name of the attribute to search for in the assertion. Conflicts with `attribute_friendly_name`.
        :param pulumi.Input[str] claim_name: For OIDC based providers, this is the name of the claim to use.
        :param pulumi.Input[Mapping[str, Any]] extra_config: Key/value attributes to add to the identity provider mapper model that is persisted to Keycloak. This can be used to extend the base model with new Keycloak features.
        :param pulumi.Input[str] name: The name of the mapper.
        """
        pulumi.set(__self__, "identity_provider_alias", identity_provider_alias)
        pulumi.set(__self__, "realm", realm)
        pulumi.set(__self__, "user_attribute", user_attribute)
        if attribute_friendly_name is not None:
            pulumi.set(__self__, "attribute_friendly_name", attribute_friendly_name)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if claim_name is not None:
            pulumi.set(__self__, "claim_name", claim_name)
        if extra_config is not None:
            pulumi.set(__self__, "extra_config", extra_config)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="identityProviderAlias")
    def identity_provider_alias(self) -> pulumi.Input[str]:
        """
        The alias of the associated identity provider.
        """
        return pulumi.get(self, "identity_provider_alias")

    @identity_provider_alias.setter
    def identity_provider_alias(self, value: pulumi.Input[str]):
        pulumi.set(self, "identity_provider_alias", value)

    @property
    @pulumi.getter
    def realm(self) -> pulumi.Input[str]:
        """
        The name of the realm.
        """
        return pulumi.get(self, "realm")

    @realm.setter
    def realm(self, value: pulumi.Input[str]):
        pulumi.set(self, "realm", value)

    @property
    @pulumi.getter(name="userAttribute")
    def user_attribute(self) -> pulumi.Input[str]:
        """
        The user attribute or property name to store the mapped result.
        """
        return pulumi.get(self, "user_attribute")

    @user_attribute.setter
    def user_attribute(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_attribute", value)

    @property
    @pulumi.getter(name="attributeFriendlyName")
    def attribute_friendly_name(self) -> Optional[pulumi.Input[str]]:
        """
        For SAML based providers, this is the friendly name of the attribute to search for in the assertion. Conflicts with `attribute_name`.
        """
        return pulumi.get(self, "attribute_friendly_name")

    @attribute_friendly_name.setter
    def attribute_friendly_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "attribute_friendly_name", value)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[pulumi.Input[str]]:
        """
        For SAML based providers, this is the name of the attribute to search for in the assertion. Conflicts with `attribute_friendly_name`.
        """
        return pulumi.get(self, "attribute_name")

    @attribute_name.setter
    def attribute_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "attribute_name", value)

    @property
    @pulumi.getter(name="claimName")
    def claim_name(self) -> Optional[pulumi.Input[str]]:
        """
        For OIDC based providers, this is the name of the claim to use.
        """
        return pulumi.get(self, "claim_name")

    @claim_name.setter
    def claim_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "claim_name", value)

    @property
    @pulumi.getter(name="extraConfig")
    def extra_config(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Key/value attributes to add to the identity provider mapper model that is persisted to Keycloak. This can be used to extend the base model with new Keycloak features.
        """
        return pulumi.get(self, "extra_config")

    @extra_config.setter
    def extra_config(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "extra_config", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the mapper.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _AttributeImporterIdentityProviderMapperState:
    def __init__(__self__, *,
                 attribute_friendly_name: Optional[pulumi.Input[str]] = None,
                 attribute_name: Optional[pulumi.Input[str]] = None,
                 claim_name: Optional[pulumi.Input[str]] = None,
                 extra_config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 identity_provider_alias: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 realm: Optional[pulumi.Input[str]] = None,
                 user_attribute: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AttributeImporterIdentityProviderMapper resources.
        :param pulumi.Input[str] attribute_friendly_name: For SAML based providers, this is the friendly name of the attribute to search for in the assertion. Conflicts with `attribute_name`.
        :param pulumi.Input[str] attribute_name: For SAML based providers, this is the name of the attribute to search for in the assertion. Conflicts with `attribute_friendly_name`.
        :param pulumi.Input[str] claim_name: For OIDC based providers, this is the name of the claim to use.
        :param pulumi.Input[Mapping[str, Any]] extra_config: Key/value attributes to add to the identity provider mapper model that is persisted to Keycloak. This can be used to extend the base model with new Keycloak features.
        :param pulumi.Input[str] identity_provider_alias: The alias of the associated identity provider.
        :param pulumi.Input[str] name: The name of the mapper.
        :param pulumi.Input[str] realm: The name of the realm.
        :param pulumi.Input[str] user_attribute: The user attribute or property name to store the mapped result.
        """
        if attribute_friendly_name is not None:
            pulumi.set(__self__, "attribute_friendly_name", attribute_friendly_name)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if claim_name is not None:
            pulumi.set(__self__, "claim_name", claim_name)
        if extra_config is not None:
            pulumi.set(__self__, "extra_config", extra_config)
        if identity_provider_alias is not None:
            pulumi.set(__self__, "identity_provider_alias", identity_provider_alias)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if realm is not None:
            pulumi.set(__self__, "realm", realm)
        if user_attribute is not None:
            pulumi.set(__self__, "user_attribute", user_attribute)

    @property
    @pulumi.getter(name="attributeFriendlyName")
    def attribute_friendly_name(self) -> Optional[pulumi.Input[str]]:
        """
        For SAML based providers, this is the friendly name of the attribute to search for in the assertion. Conflicts with `attribute_name`.
        """
        return pulumi.get(self, "attribute_friendly_name")

    @attribute_friendly_name.setter
    def attribute_friendly_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "attribute_friendly_name", value)

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[pulumi.Input[str]]:
        """
        For SAML based providers, this is the name of the attribute to search for in the assertion. Conflicts with `attribute_friendly_name`.
        """
        return pulumi.get(self, "attribute_name")

    @attribute_name.setter
    def attribute_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "attribute_name", value)

    @property
    @pulumi.getter(name="claimName")
    def claim_name(self) -> Optional[pulumi.Input[str]]:
        """
        For OIDC based providers, this is the name of the claim to use.
        """
        return pulumi.get(self, "claim_name")

    @claim_name.setter
    def claim_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "claim_name", value)

    @property
    @pulumi.getter(name="extraConfig")
    def extra_config(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Key/value attributes to add to the identity provider mapper model that is persisted to Keycloak. This can be used to extend the base model with new Keycloak features.
        """
        return pulumi.get(self, "extra_config")

    @extra_config.setter
    def extra_config(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "extra_config", value)

    @property
    @pulumi.getter(name="identityProviderAlias")
    def identity_provider_alias(self) -> Optional[pulumi.Input[str]]:
        """
        The alias of the associated identity provider.
        """
        return pulumi.get(self, "identity_provider_alias")

    @identity_provider_alias.setter
    def identity_provider_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "identity_provider_alias", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the mapper.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def realm(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the realm.
        """
        return pulumi.get(self, "realm")

    @realm.setter
    def realm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "realm", value)

    @property
    @pulumi.getter(name="userAttribute")
    def user_attribute(self) -> Optional[pulumi.Input[str]]:
        """
        The user attribute or property name to store the mapped result.
        """
        return pulumi.get(self, "user_attribute")

    @user_attribute.setter
    def user_attribute(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_attribute", value)


class AttributeImporterIdentityProviderMapper(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attribute_friendly_name: Optional[pulumi.Input[str]] = None,
                 attribute_name: Optional[pulumi.Input[str]] = None,
                 claim_name: Optional[pulumi.Input[str]] = None,
                 extra_config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 identity_provider_alias: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 realm: Optional[pulumi.Input[str]] = None,
                 user_attribute: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Allows for creating and managing an attribute importer identity provider mapper within Keycloak.

        The attribute importer mapper can be used to map attributes from externally defined users to attributes or properties of the imported Keycloak user:
        - For the OIDC identity provider, this will map a claim on the ID or access token to an attribute for the imported Keycloak user.
        - For the SAML identity provider, this will map a SAML attribute found within the assertion to an attribute for the imported Keycloak user.
        - For social identity providers, this will map a JSON field from the user profile to an attribute for the imported Keycloak user.

        > If you are using Keycloak 10 or higher, you will need to specify the `extra_config` argument in order to define a `syncMode` for the mapper.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_keycloak as keycloak

        realm = keycloak.Realm("realm",
            realm="my-realm",
            enabled=True)
        oidc_identity_provider = keycloak.oidc.IdentityProvider("oidcIdentityProvider",
            realm=realm.id,
            alias="oidc",
            authorization_url="https://example.com/auth",
            token_url="https://example.com/token",
            client_id="example_id",
            client_secret="example_token",
            default_scopes="openid random profile")
        oidc_attribute_importer_identity_provider_mapper = keycloak.AttributeImporterIdentityProviderMapper("oidcAttributeImporterIdentityProviderMapper",
            realm=realm.id,
            claim_name="my-email-claim",
            identity_provider_alias=oidc_identity_provider.alias,
            user_attribute="email",
            extra_config={
                "syncMode": "INHERIT",
            })
        ```

        ## Import

        Identity provider mappers can be imported using the format `{{realm_id}}/{{idp_alias}}/{{idp_mapper_id}}`, where `idp_alias` is the identity provider alias, and `idp_mapper_id` is the unique ID that Keycloak assigns to the mapper upon creation. This value can be found in the URI when editing this mapper in the GUI, and is typically a GUID. Examplebash

        ```sh
         $ pulumi import keycloak:index/attributeImporterIdentityProviderMapper:AttributeImporterIdentityProviderMapper test_mapper my-realm/my-mapper/f446db98-7133-4e30-b18a-3d28fde7ca1b
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] attribute_friendly_name: For SAML based providers, this is the friendly name of the attribute to search for in the assertion. Conflicts with `attribute_name`.
        :param pulumi.Input[str] attribute_name: For SAML based providers, this is the name of the attribute to search for in the assertion. Conflicts with `attribute_friendly_name`.
        :param pulumi.Input[str] claim_name: For OIDC based providers, this is the name of the claim to use.
        :param pulumi.Input[Mapping[str, Any]] extra_config: Key/value attributes to add to the identity provider mapper model that is persisted to Keycloak. This can be used to extend the base model with new Keycloak features.
        :param pulumi.Input[str] identity_provider_alias: The alias of the associated identity provider.
        :param pulumi.Input[str] name: The name of the mapper.
        :param pulumi.Input[str] realm: The name of the realm.
        :param pulumi.Input[str] user_attribute: The user attribute or property name to store the mapped result.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AttributeImporterIdentityProviderMapperArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Allows for creating and managing an attribute importer identity provider mapper within Keycloak.

        The attribute importer mapper can be used to map attributes from externally defined users to attributes or properties of the imported Keycloak user:
        - For the OIDC identity provider, this will map a claim on the ID or access token to an attribute for the imported Keycloak user.
        - For the SAML identity provider, this will map a SAML attribute found within the assertion to an attribute for the imported Keycloak user.
        - For social identity providers, this will map a JSON field from the user profile to an attribute for the imported Keycloak user.

        > If you are using Keycloak 10 or higher, you will need to specify the `extra_config` argument in order to define a `syncMode` for the mapper.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_keycloak as keycloak

        realm = keycloak.Realm("realm",
            realm="my-realm",
            enabled=True)
        oidc_identity_provider = keycloak.oidc.IdentityProvider("oidcIdentityProvider",
            realm=realm.id,
            alias="oidc",
            authorization_url="https://example.com/auth",
            token_url="https://example.com/token",
            client_id="example_id",
            client_secret="example_token",
            default_scopes="openid random profile")
        oidc_attribute_importer_identity_provider_mapper = keycloak.AttributeImporterIdentityProviderMapper("oidcAttributeImporterIdentityProviderMapper",
            realm=realm.id,
            claim_name="my-email-claim",
            identity_provider_alias=oidc_identity_provider.alias,
            user_attribute="email",
            extra_config={
                "syncMode": "INHERIT",
            })
        ```

        ## Import

        Identity provider mappers can be imported using the format `{{realm_id}}/{{idp_alias}}/{{idp_mapper_id}}`, where `idp_alias` is the identity provider alias, and `idp_mapper_id` is the unique ID that Keycloak assigns to the mapper upon creation. This value can be found in the URI when editing this mapper in the GUI, and is typically a GUID. Examplebash

        ```sh
         $ pulumi import keycloak:index/attributeImporterIdentityProviderMapper:AttributeImporterIdentityProviderMapper test_mapper my-realm/my-mapper/f446db98-7133-4e30-b18a-3d28fde7ca1b
        ```

        :param str resource_name: The name of the resource.
        :param AttributeImporterIdentityProviderMapperArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AttributeImporterIdentityProviderMapperArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attribute_friendly_name: Optional[pulumi.Input[str]] = None,
                 attribute_name: Optional[pulumi.Input[str]] = None,
                 claim_name: Optional[pulumi.Input[str]] = None,
                 extra_config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 identity_provider_alias: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 realm: Optional[pulumi.Input[str]] = None,
                 user_attribute: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AttributeImporterIdentityProviderMapperArgs.__new__(AttributeImporterIdentityProviderMapperArgs)

            __props__.__dict__["attribute_friendly_name"] = attribute_friendly_name
            __props__.__dict__["attribute_name"] = attribute_name
            __props__.__dict__["claim_name"] = claim_name
            __props__.__dict__["extra_config"] = extra_config
            if identity_provider_alias is None and not opts.urn:
                raise TypeError("Missing required property 'identity_provider_alias'")
            __props__.__dict__["identity_provider_alias"] = identity_provider_alias
            __props__.__dict__["name"] = name
            if realm is None and not opts.urn:
                raise TypeError("Missing required property 'realm'")
            __props__.__dict__["realm"] = realm
            if user_attribute is None and not opts.urn:
                raise TypeError("Missing required property 'user_attribute'")
            __props__.__dict__["user_attribute"] = user_attribute
        super(AttributeImporterIdentityProviderMapper, __self__).__init__(
            'keycloak:index/attributeImporterIdentityProviderMapper:AttributeImporterIdentityProviderMapper',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            attribute_friendly_name: Optional[pulumi.Input[str]] = None,
            attribute_name: Optional[pulumi.Input[str]] = None,
            claim_name: Optional[pulumi.Input[str]] = None,
            extra_config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            identity_provider_alias: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            realm: Optional[pulumi.Input[str]] = None,
            user_attribute: Optional[pulumi.Input[str]] = None) -> 'AttributeImporterIdentityProviderMapper':
        """
        Get an existing AttributeImporterIdentityProviderMapper resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] attribute_friendly_name: For SAML based providers, this is the friendly name of the attribute to search for in the assertion. Conflicts with `attribute_name`.
        :param pulumi.Input[str] attribute_name: For SAML based providers, this is the name of the attribute to search for in the assertion. Conflicts with `attribute_friendly_name`.
        :param pulumi.Input[str] claim_name: For OIDC based providers, this is the name of the claim to use.
        :param pulumi.Input[Mapping[str, Any]] extra_config: Key/value attributes to add to the identity provider mapper model that is persisted to Keycloak. This can be used to extend the base model with new Keycloak features.
        :param pulumi.Input[str] identity_provider_alias: The alias of the associated identity provider.
        :param pulumi.Input[str] name: The name of the mapper.
        :param pulumi.Input[str] realm: The name of the realm.
        :param pulumi.Input[str] user_attribute: The user attribute or property name to store the mapped result.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AttributeImporterIdentityProviderMapperState.__new__(_AttributeImporterIdentityProviderMapperState)

        __props__.__dict__["attribute_friendly_name"] = attribute_friendly_name
        __props__.__dict__["attribute_name"] = attribute_name
        __props__.__dict__["claim_name"] = claim_name
        __props__.__dict__["extra_config"] = extra_config
        __props__.__dict__["identity_provider_alias"] = identity_provider_alias
        __props__.__dict__["name"] = name
        __props__.__dict__["realm"] = realm
        __props__.__dict__["user_attribute"] = user_attribute
        return AttributeImporterIdentityProviderMapper(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="attributeFriendlyName")
    def attribute_friendly_name(self) -> pulumi.Output[Optional[str]]:
        """
        For SAML based providers, this is the friendly name of the attribute to search for in the assertion. Conflicts with `attribute_name`.
        """
        return pulumi.get(self, "attribute_friendly_name")

    @property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> pulumi.Output[Optional[str]]:
        """
        For SAML based providers, this is the name of the attribute to search for in the assertion. Conflicts with `attribute_friendly_name`.
        """
        return pulumi.get(self, "attribute_name")

    @property
    @pulumi.getter(name="claimName")
    def claim_name(self) -> pulumi.Output[Optional[str]]:
        """
        For OIDC based providers, this is the name of the claim to use.
        """
        return pulumi.get(self, "claim_name")

    @property
    @pulumi.getter(name="extraConfig")
    def extra_config(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        Key/value attributes to add to the identity provider mapper model that is persisted to Keycloak. This can be used to extend the base model with new Keycloak features.
        """
        return pulumi.get(self, "extra_config")

    @property
    @pulumi.getter(name="identityProviderAlias")
    def identity_provider_alias(self) -> pulumi.Output[str]:
        """
        The alias of the associated identity provider.
        """
        return pulumi.get(self, "identity_provider_alias")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the mapper.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def realm(self) -> pulumi.Output[str]:
        """
        The name of the realm.
        """
        return pulumi.get(self, "realm")

    @property
    @pulumi.getter(name="userAttribute")
    def user_attribute(self) -> pulumi.Output[str]:
        """
        The user attribute or property name to store the mapped result.
        """
        return pulumi.get(self, "user_attribute")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['HardcodedRoleMapperArgs', 'HardcodedRoleMapper']

@pulumi.input_type
class HardcodedRoleMapperArgs:
    def __init__(__self__, *,
                 ldap_user_federation_id: pulumi.Input[str],
                 realm_id: pulumi.Input[str],
                 role: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a HardcodedRoleMapper resource.
        :param pulumi.Input[str] ldap_user_federation_id: The ID of the LDAP user federation provider to attach this mapper to.
        :param pulumi.Input[str] realm_id: The realm that this LDAP mapper will exist in.
        :param pulumi.Input[str] role: The name of the role which should be assigned to the users. Client roles should use the format `{{client_id}}.{{client_role_name}}`.
        :param pulumi.Input[str] name: Display name of this mapper when displayed in the console.
        """
        pulumi.set(__self__, "ldap_user_federation_id", ldap_user_federation_id)
        pulumi.set(__self__, "realm_id", realm_id)
        pulumi.set(__self__, "role", role)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="ldapUserFederationId")
    def ldap_user_federation_id(self) -> pulumi.Input[str]:
        """
        The ID of the LDAP user federation provider to attach this mapper to.
        """
        return pulumi.get(self, "ldap_user_federation_id")

    @ldap_user_federation_id.setter
    def ldap_user_federation_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "ldap_user_federation_id", value)

    @property
    @pulumi.getter(name="realmId")
    def realm_id(self) -> pulumi.Input[str]:
        """
        The realm that this LDAP mapper will exist in.
        """
        return pulumi.get(self, "realm_id")

    @realm_id.setter
    def realm_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "realm_id", value)

    @property
    @pulumi.getter
    def role(self) -> pulumi.Input[str]:
        """
        The name of the role which should be assigned to the users. Client roles should use the format `{{client_id}}.{{client_role_name}}`.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[str]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Display name of this mapper when displayed in the console.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _HardcodedRoleMapperState:
    def __init__(__self__, *,
                 ldap_user_federation_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 realm_id: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering HardcodedRoleMapper resources.
        :param pulumi.Input[str] ldap_user_federation_id: The ID of the LDAP user federation provider to attach this mapper to.
        :param pulumi.Input[str] name: Display name of this mapper when displayed in the console.
        :param pulumi.Input[str] realm_id: The realm that this LDAP mapper will exist in.
        :param pulumi.Input[str] role: The name of the role which should be assigned to the users. Client roles should use the format `{{client_id}}.{{client_role_name}}`.
        """
        if ldap_user_federation_id is not None:
            pulumi.set(__self__, "ldap_user_federation_id", ldap_user_federation_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if realm_id is not None:
            pulumi.set(__self__, "realm_id", realm_id)
        if role is not None:
            pulumi.set(__self__, "role", role)

    @property
    @pulumi.getter(name="ldapUserFederationId")
    def ldap_user_federation_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the LDAP user federation provider to attach this mapper to.
        """
        return pulumi.get(self, "ldap_user_federation_id")

    @ldap_user_federation_id.setter
    def ldap_user_federation_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ldap_user_federation_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Display name of this mapper when displayed in the console.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="realmId")
    def realm_id(self) -> Optional[pulumi.Input[str]]:
        """
        The realm that this LDAP mapper will exist in.
        """
        return pulumi.get(self, "realm_id")

    @realm_id.setter
    def realm_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "realm_id", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the role which should be assigned to the users. Client roles should use the format `{{client_id}}.{{client_role_name}}`.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)


class HardcodedRoleMapper(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ldap_user_federation_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 realm_id: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Allows for creating and managing hardcoded role mappers for Keycloak users federated via LDAP.

        The LDAP hardcoded role mapper will grant a specified Keycloak role to each Keycloak user linked with LDAP.

        ## Example Usage
        ### Realm Role)

        ```python
        import pulumi
        import pulumi_keycloak as keycloak

        realm = keycloak.Realm("realm",
            realm="my-realm",
            enabled=True)
        ldap_user_federation = keycloak.ldap.UserFederation("ldapUserFederation",
            realm_id=realm.id,
            username_ldap_attribute="cn",
            rdn_ldap_attribute="cn",
            uuid_ldap_attribute="entryDN",
            user_object_classes=[
                "simpleSecurityObject",
                "organizationalRole",
            ],
            connection_url="ldap://openldap",
            users_dn="dc=example,dc=org",
            bind_dn="cn=admin,dc=example,dc=org",
            bind_credential="admin")
        realm_admin_role = keycloak.Role("realmAdminRole",
            realm_id=realm.id,
            description="My Realm Role")
        assign_admin_role_to_all_users = keycloak.ldap.HardcodedRoleMapper("assignAdminRoleToAllUsers",
            realm_id=realm.id,
            ldap_user_federation_id=ldap_user_federation.id,
            role=realm_admin_role.name)
        ```
        ### Client Role)

        ```python
        import pulumi
        import pulumi_keycloak as keycloak

        realm = keycloak.Realm("realm",
            realm="my-realm",
            enabled=True)
        ldap_user_federation = keycloak.ldap.UserFederation("ldapUserFederation",
            realm_id=realm.id,
            username_ldap_attribute="cn",
            rdn_ldap_attribute="cn",
            uuid_ldap_attribute="entryDN",
            user_object_classes=[
                "simpleSecurityObject",
                "organizationalRole",
            ],
            connection_url="ldap://openldap",
            users_dn="dc=example,dc=org",
            bind_dn="cn=admin,dc=example,dc=org",
            bind_credential="admin")
        realm_management = keycloak.openid.get_client_output(realm_id=realm.id,
            client_id="realm-management")
        create_client = pulumi.Output.all(realm.id, realm_management).apply(lambda id, realm_management: keycloak.get_role_output(realm_id=id,
            client_id=realm_management.id,
            name="create-client"))
        assign_admin_role_to_all_users = keycloak.ldap.HardcodedRoleMapper("assignAdminRoleToAllUsers",
            realm_id=realm.id,
            ldap_user_federation_id=ldap_user_federation.id,
            role=pulumi.Output.all(realm_management, create_client).apply(lambda realm_management, create_client: f"{realm_management.client_id}.{create_client.name}"))
        ```

        ## Import

        LDAP mappers can be imported using the format `{{realm_id}}/{{ldap_user_federation_id}}/{{ldap_mapper_id}}`. The ID of the LDAP user federation provider and the mapper can be found within the Keycloak GUI, and they are typically GUIDs. Examplebash

        ```sh
         $ pulumi import keycloak:ldap/hardcodedRoleMapper:HardcodedRoleMapper assign_admin_role_to_all_users my-realm/af2a6ca3-e4d7-49c3-b08b-1b3c70b4b860/3d923ece-1a91-4bf7-adaf-3b82f2a12b67
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ldap_user_federation_id: The ID of the LDAP user federation provider to attach this mapper to.
        :param pulumi.Input[str] name: Display name of this mapper when displayed in the console.
        :param pulumi.Input[str] realm_id: The realm that this LDAP mapper will exist in.
        :param pulumi.Input[str] role: The name of the role which should be assigned to the users. Client roles should use the format `{{client_id}}.{{client_role_name}}`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HardcodedRoleMapperArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Allows for creating and managing hardcoded role mappers for Keycloak users federated via LDAP.

        The LDAP hardcoded role mapper will grant a specified Keycloak role to each Keycloak user linked with LDAP.

        ## Example Usage
        ### Realm Role)

        ```python
        import pulumi
        import pulumi_keycloak as keycloak

        realm = keycloak.Realm("realm",
            realm="my-realm",
            enabled=True)
        ldap_user_federation = keycloak.ldap.UserFederation("ldapUserFederation",
            realm_id=realm.id,
            username_ldap_attribute="cn",
            rdn_ldap_attribute="cn",
            uuid_ldap_attribute="entryDN",
            user_object_classes=[
                "simpleSecurityObject",
                "organizationalRole",
            ],
            connection_url="ldap://openldap",
            users_dn="dc=example,dc=org",
            bind_dn="cn=admin,dc=example,dc=org",
            bind_credential="admin")
        realm_admin_role = keycloak.Role("realmAdminRole",
            realm_id=realm.id,
            description="My Realm Role")
        assign_admin_role_to_all_users = keycloak.ldap.HardcodedRoleMapper("assignAdminRoleToAllUsers",
            realm_id=realm.id,
            ldap_user_federation_id=ldap_user_federation.id,
            role=realm_admin_role.name)
        ```
        ### Client Role)

        ```python
        import pulumi
        import pulumi_keycloak as keycloak

        realm = keycloak.Realm("realm",
            realm="my-realm",
            enabled=True)
        ldap_user_federation = keycloak.ldap.UserFederation("ldapUserFederation",
            realm_id=realm.id,
            username_ldap_attribute="cn",
            rdn_ldap_attribute="cn",
            uuid_ldap_attribute="entryDN",
            user_object_classes=[
                "simpleSecurityObject",
                "organizationalRole",
            ],
            connection_url="ldap://openldap",
            users_dn="dc=example,dc=org",
            bind_dn="cn=admin,dc=example,dc=org",
            bind_credential="admin")
        realm_management = keycloak.openid.get_client_output(realm_id=realm.id,
            client_id="realm-management")
        create_client = pulumi.Output.all(realm.id, realm_management).apply(lambda id, realm_management: keycloak.get_role_output(realm_id=id,
            client_id=realm_management.id,
            name="create-client"))
        assign_admin_role_to_all_users = keycloak.ldap.HardcodedRoleMapper("assignAdminRoleToAllUsers",
            realm_id=realm.id,
            ldap_user_federation_id=ldap_user_federation.id,
            role=pulumi.Output.all(realm_management, create_client).apply(lambda realm_management, create_client: f"{realm_management.client_id}.{create_client.name}"))
        ```

        ## Import

        LDAP mappers can be imported using the format `{{realm_id}}/{{ldap_user_federation_id}}/{{ldap_mapper_id}}`. The ID of the LDAP user federation provider and the mapper can be found within the Keycloak GUI, and they are typically GUIDs. Examplebash

        ```sh
         $ pulumi import keycloak:ldap/hardcodedRoleMapper:HardcodedRoleMapper assign_admin_role_to_all_users my-realm/af2a6ca3-e4d7-49c3-b08b-1b3c70b4b860/3d923ece-1a91-4bf7-adaf-3b82f2a12b67
        ```

        :param str resource_name: The name of the resource.
        :param HardcodedRoleMapperArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HardcodedRoleMapperArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ldap_user_federation_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 realm_id: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HardcodedRoleMapperArgs.__new__(HardcodedRoleMapperArgs)

            if ldap_user_federation_id is None and not opts.urn:
                raise TypeError("Missing required property 'ldap_user_federation_id'")
            __props__.__dict__["ldap_user_federation_id"] = ldap_user_federation_id
            __props__.__dict__["name"] = name
            if realm_id is None and not opts.urn:
                raise TypeError("Missing required property 'realm_id'")
            __props__.__dict__["realm_id"] = realm_id
            if role is None and not opts.urn:
                raise TypeError("Missing required property 'role'")
            __props__.__dict__["role"] = role
        super(HardcodedRoleMapper, __self__).__init__(
            'keycloak:ldap/hardcodedRoleMapper:HardcodedRoleMapper',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ldap_user_federation_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            realm_id: Optional[pulumi.Input[str]] = None,
            role: Optional[pulumi.Input[str]] = None) -> 'HardcodedRoleMapper':
        """
        Get an existing HardcodedRoleMapper resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ldap_user_federation_id: The ID of the LDAP user federation provider to attach this mapper to.
        :param pulumi.Input[str] name: Display name of this mapper when displayed in the console.
        :param pulumi.Input[str] realm_id: The realm that this LDAP mapper will exist in.
        :param pulumi.Input[str] role: The name of the role which should be assigned to the users. Client roles should use the format `{{client_id}}.{{client_role_name}}`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HardcodedRoleMapperState.__new__(_HardcodedRoleMapperState)

        __props__.__dict__["ldap_user_federation_id"] = ldap_user_federation_id
        __props__.__dict__["name"] = name
        __props__.__dict__["realm_id"] = realm_id
        __props__.__dict__["role"] = role
        return HardcodedRoleMapper(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="ldapUserFederationId")
    def ldap_user_federation_id(self) -> pulumi.Output[str]:
        """
        The ID of the LDAP user federation provider to attach this mapper to.
        """
        return pulumi.get(self, "ldap_user_federation_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Display name of this mapper when displayed in the console.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="realmId")
    def realm_id(self) -> pulumi.Output[str]:
        """
        The realm that this LDAP mapper will exist in.
        """
        return pulumi.get(self, "realm_id")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[str]:
        """
        The name of the role which should be assigned to the users. Client roles should use the format `{{client_id}}.{{client_role_name}}`.
        """
        return pulumi.get(self, "role")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .attribute_importer_identity_provider_mapper import *
from .attribute_to_role_identity_mapper import *
from .custom_identity_provider_mapping import *
from .custom_user_federation import *
from .default_groups import *
from .default_roles import *
from .generic_client_protocol_mapper import *
from .generic_client_role_mapper import *
from .get_authentication_execution import *
from .get_authentication_flow import *
from .get_client_description_converter import *
from .get_group import *
from .get_realm import *
from .get_realm_keys import *
from .get_role import *
from .get_user import *
from .get_user_realm_roles import *
from .group import *
from .group_memberships import *
from .group_permissions import *
from .group_roles import *
from .hardcoded_attribute_identity_provider_mapper import *
from .hardcoded_role_identity_mapper import *
from .identity_provider_token_exchange_scope_permission import *
from .provider import *
from .realm import *
from .realm_events import *
from .realm_keystore_aes_generated import *
from .realm_keystore_ecdsa_generated import *
from .realm_keystore_hmac_generated import *
from .realm_keystore_java_generated import *
from .realm_keystore_rsa import *
from .realm_keystore_rsa_generated import *
from .required_action import *
from .role import *
from .user import *
from .user_groups import *
from .user_roles import *
from .user_template_importer_identity_provider_mapper import *
from .users_permissions import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_keycloak.authentication as __authentication
    authentication = __authentication
    import pulumi_keycloak.config as __config
    config = __config
    import pulumi_keycloak.ldap as __ldap
    ldap = __ldap
    import pulumi_keycloak.oidc as __oidc
    oidc = __oidc
    import pulumi_keycloak.openid as __openid
    openid = __openid
    import pulumi_keycloak.saml as __saml
    saml = __saml
else:
    authentication = _utilities.lazy_import('pulumi_keycloak.authentication')
    config = _utilities.lazy_import('pulumi_keycloak.config')
    ldap = _utilities.lazy_import('pulumi_keycloak.ldap')
    oidc = _utilities.lazy_import('pulumi_keycloak.oidc')
    openid = _utilities.lazy_import('pulumi_keycloak.openid')
    saml = _utilities.lazy_import('pulumi_keycloak.saml')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "keycloak",
  "mod": "authentication/execution",
  "fqn": "pulumi_keycloak.authentication",
  "classes": {
   "keycloak:authentication/execution:Execution": "Execution"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "authentication/executionConfig",
  "fqn": "pulumi_keycloak.authentication",
  "classes": {
   "keycloak:authentication/executionConfig:ExecutionConfig": "ExecutionConfig"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "authentication/flow",
  "fqn": "pulumi_keycloak.authentication",
  "classes": {
   "keycloak:authentication/flow:Flow": "Flow"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "authentication/subflow",
  "fqn": "pulumi_keycloak.authentication",
  "classes": {
   "keycloak:authentication/subflow:Subflow": "Subflow"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/attributeImporterIdentityProviderMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/attributeImporterIdentityProviderMapper:AttributeImporterIdentityProviderMapper": "AttributeImporterIdentityProviderMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/attributeToRoleIdentityMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/attributeToRoleIdentityMapper:AttributeToRoleIdentityMapper": "AttributeToRoleIdentityMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/customIdentityProviderMapping",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/customIdentityProviderMapping:CustomIdentityProviderMapping": "CustomIdentityProviderMapping"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/customUserFederation",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/customUserFederation:CustomUserFederation": "CustomUserFederation"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/defaultGroups",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/defaultGroups:DefaultGroups": "DefaultGroups"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/defaultRoles",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/defaultRoles:DefaultRoles": "DefaultRoles"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/genericClientProtocolMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/genericClientProtocolMapper:GenericClientProtocolMapper": "GenericClientProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/genericClientRoleMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/genericClientRoleMapper:GenericClientRoleMapper": "GenericClientRoleMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/group",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/group:Group": "Group"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/groupMemberships",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/groupMemberships:GroupMemberships": "GroupMemberships"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/groupPermissions",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/groupPermissions:GroupPermissions": "GroupPermissions"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/groupRoles",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/groupRoles:GroupRoles": "GroupRoles"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/hardcodedAttributeIdentityProviderMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/hardcodedAttributeIdentityProviderMapper:HardcodedAttributeIdentityProviderMapper": "HardcodedAttributeIdentityProviderMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/hardcodedRoleIdentityMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/hardcodedRoleIdentityMapper:HardcodedRoleIdentityMapper": "HardcodedRoleIdentityMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/identityProviderTokenExchangeScopePermission",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/identityProviderTokenExchangeScopePermission:IdentityProviderTokenExchangeScopePermission": "IdentityProviderTokenExchangeScopePermission"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realm",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realm:Realm": "Realm"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmEvents",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmEvents:RealmEvents": "RealmEvents"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreAesGenerated",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreAesGenerated:RealmKeystoreAesGenerated": "RealmKeystoreAesGenerated"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreEcdsaGenerated",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreEcdsaGenerated:RealmKeystoreEcdsaGenerated": "RealmKeystoreEcdsaGenerated"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreHmacGenerated",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreHmacGenerated:RealmKeystoreHmacGenerated": "RealmKeystoreHmacGenerated"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreJavaGenerated",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreJavaGenerated:RealmKeystoreJavaGenerated": "RealmKeystoreJavaGenerated"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreRsa",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreRsa:RealmKeystoreRsa": "RealmKeystoreRsa"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreRsaGenerated",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreRsaGenerated:RealmKeystoreRsaGenerated": "RealmKeystoreRsaGenerated"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/requiredAction",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/requiredAction:RequiredAction": "RequiredAction"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/role",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/role:Role": "Role"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/user",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/user:User": "User"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/userGroups",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/userGroups:UserGroups": "UserGroups"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/userRoles",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/userRoles:UserRoles": "UserRoles"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/userTemplateImporterIdentityProviderMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/userTemplateImporterIdentityProviderMapper:UserTemplateImporterIdentityProviderMapper": "UserTemplateImporterIdentityProviderMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/usersPermissions",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/usersPermissions:UsersPermissions": "UsersPermissions"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/fullNameMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/fullNameMapper:FullNameMapper": "FullNameMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/groupMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/groupMapper:GroupMapper": "GroupMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/hardcodedGroupMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/hardcodedGroupMapper:HardcodedGroupMapper": "HardcodedGroupMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/hardcodedRoleMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/hardcodedRoleMapper:HardcodedRoleMapper": "HardcodedRoleMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/msadLdsUserAccountControlMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/msadLdsUserAccountControlMapper:MsadLdsUserAccountControlMapper": "MsadLdsUserAccountControlMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/msadUserAccountControlMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/msadUserAccountControlMapper:MsadUserAccountControlMapper": "MsadUserAccountControlMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/roleMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/roleMapper:RoleMapper": "RoleMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/userAttributeMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/userAttributeMapper:UserAttributeMapper": "UserAttributeMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/userFederation",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/userFederation:UserFederation": "UserFederation"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "oidc/googleIdentityProvider",
  "fqn": "pulumi_keycloak.oidc",
  "classes": {
   "keycloak:oidc/googleIdentityProvider:GoogleIdentityProvider": "GoogleIdentityProvider"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "oidc/identityProvider",
  "fqn": "pulumi_keycloak.oidc",
  "classes": {
   "keycloak:oidc/identityProvider:IdentityProvider": "IdentityProvider"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/audienceProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/audienceProtocolMapper:AudienceProtocolMapper": "AudienceProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/audienceResolveProtocolMappter",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/audienceResolveProtocolMappter:AudienceResolveProtocolMappter": "AudienceResolveProtocolMappter"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/client",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/client:Client": "Client"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientAggregatePolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientAggregatePolicy:ClientAggregatePolicy": "ClientAggregatePolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientAuthorizationPermission",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientAuthorizationPermission:ClientAuthorizationPermission": "ClientAuthorizationPermission"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientAuthorizationResource",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientAuthorizationResource:ClientAuthorizationResource": "ClientAuthorizationResource"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientAuthorizationScope",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientAuthorizationScope:ClientAuthorizationScope": "ClientAuthorizationScope"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientDefaultScopes",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientDefaultScopes:ClientDefaultScopes": "ClientDefaultScopes"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientGroupPolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientGroupPolicy:ClientGroupPolicy": "ClientGroupPolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientJsPolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientJsPolicy:ClientJsPolicy": "ClientJsPolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientOptionalScopes",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientOptionalScopes:ClientOptionalScopes": "ClientOptionalScopes"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientPermissions",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientPermissions:ClientPermissions": "ClientPermissions"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientPolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientPolicy:ClientPolicy": "ClientPolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientRolePolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientRolePolicy:ClientRolePolicy": "ClientRolePolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientScope",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientScope:ClientScope": "ClientScope"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientServiceAccountRealmRole",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientServiceAccountRealmRole:ClientServiceAccountRealmRole": "ClientServiceAccountRealmRole"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientServiceAccountRole",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientServiceAccountRole:ClientServiceAccountRole": "ClientServiceAccountRole"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientTimePolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientTimePolicy:ClientTimePolicy": "ClientTimePolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientUserPolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientUserPolicy:ClientUserPolicy": "ClientUserPolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/fullNameProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/fullNameProtocolMapper:FullNameProtocolMapper": "FullNameProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/groupMembershipProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/groupMembershipProtocolMapper:GroupMembershipProtocolMapper": "GroupMembershipProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/hardcodedClaimProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/hardcodedClaimProtocolMapper:HardcodedClaimProtocolMapper": "HardcodedClaimProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/hardcodedRoleProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/hardcodedRoleProtocolMapper:HardcodedRoleProtocolMapper": "HardcodedRoleProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/scriptProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/scriptProtocolMapper:ScriptProtocolMapper": "ScriptProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/userAttributeProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/userAttributeProtocolMapper:UserAttributeProtocolMapper": "UserAttributeProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/userClientRoleProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/userClientRoleProtocolMapper:UserClientRoleProtocolMapper": "UserClientRoleProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/userPropertyProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/userPropertyProtocolMapper:UserPropertyProtocolMapper": "UserPropertyProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/userRealmRoleProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/userRealmRoleProtocolMapper:UserRealmRoleProtocolMapper": "UserRealmRoleProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/userSessionNoteProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/userSessionNoteProtocolMapper:UserSessionNoteProtocolMapper": "UserSessionNoteProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/client",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/client:Client": "Client"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/clientDefaultScope",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/clientDefaultScope:ClientDefaultScope": "ClientDefaultScope"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/clientScope",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/clientScope:ClientScope": "ClientScope"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/identityProvider",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/identityProvider:IdentityProvider": "IdentityProvider"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/scriptProtocolMapper",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/scriptProtocolMapper:ScriptProtocolMapper": "ScriptProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/userAttributeProtocolMapper",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/userAttributeProtocolMapper:UserAttributeProtocolMapper": "UserAttributeProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/userPropertyProtocolMapper",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/userPropertyProtocolMapper:UserPropertyProtocolMapper": "UserPropertyProtocolMapper"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "keycloak",
  "token": "pulumi:providers:keycloak",
  "fqn": "pulumi_keycloak",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ClientTimePolicyArgs', 'ClientTimePolicy']

@pulumi.input_type
class ClientTimePolicyArgs:
    def __init__(__self__, *,
                 decision_strategy: pulumi.Input[str],
                 realm_id: pulumi.Input[str],
                 resource_server_id: pulumi.Input[str],
                 day_month: Optional[pulumi.Input[str]] = None,
                 day_month_end: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 hour: Optional[pulumi.Input[str]] = None,
                 hour_end: Optional[pulumi.Input[str]] = None,
                 logic: Optional[pulumi.Input[str]] = None,
                 minute: Optional[pulumi.Input[str]] = None,
                 minute_end: Optional[pulumi.Input[str]] = None,
                 month: Optional[pulumi.Input[str]] = None,
                 month_end: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 not_before: Optional[pulumi.Input[str]] = None,
                 not_on_or_after: Optional[pulumi.Input[str]] = None,
                 year: Optional[pulumi.Input[str]] = None,
                 year_end: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ClientTimePolicy resource.
        """
        pulumi.set(__self__, "decision_strategy", decision_strategy)
        pulumi.set(__self__, "realm_id", realm_id)
        pulumi.set(__self__, "resource_server_id", resource_server_id)
        if day_month is not None:
            pulumi.set(__self__, "day_month", day_month)
        if day_month_end is not None:
            pulumi.set(__self__, "day_month_end", day_month_end)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if hour is not None:
            pulumi.set(__self__, "hour", hour)
        if hour_end is not None:
            pulumi.set(__self__, "hour_end", hour_end)
        if logic is not None:
            pulumi.set(__self__, "logic", logic)
        if minute is not None:
            pulumi.set(__self__, "minute", minute)
        if minute_end is not None:
            pulumi.set(__self__, "minute_end", minute_end)
        if month is not None:
            pulumi.set(__self__, "month", month)
        if month_end is not None:
            pulumi.set(__self__, "month_end", month_end)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if not_before is not None:
            pulumi.set(__self__, "not_before", not_before)
        if not_on_or_after is not None:
            pulumi.set(__self__, "not_on_or_after", not_on_or_after)
        if year is not None:
            pulumi.set(__self__, "year", year)
        if year_end is not None:
            pulumi.set(__self__, "year_end", year_end)

    @property
    @pulumi.getter(name="decisionStrategy")
    def decision_strategy(self) -> pulumi.Input[str]:
        return pulumi.get(self, "decision_strategy")

    @decision_strategy.setter
    def decision_strategy(self, value: pulumi.Input[str]):
        pulumi.set(self, "decision_strategy", value)

    @property
    @pulumi.getter(name="realmId")
    def realm_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "realm_id")

    @realm_id.setter
    def realm_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "realm_id", value)

    @property
    @pulumi.getter(name="resourceServerId")
    def resource_server_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "resource_server_id")

    @resource_server_id.setter
    def resource_server_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_server_id", value)

    @property
    @pulumi.getter(name="dayMonth")
    def day_month(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "day_month")

    @day_month.setter
    def day_month(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "day_month", value)

    @property
    @pulumi.getter(name="dayMonthEnd")
    def day_month_end(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "day_month_end")

    @day_month_end.setter
    def day_month_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "day_month_end", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def hour(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "hour")

    @hour.setter
    def hour(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hour", value)

    @property
    @pulumi.getter(name="hourEnd")
    def hour_end(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "hour_end")

    @hour_end.setter
    def hour_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hour_end", value)

    @property
    @pulumi.getter
    def logic(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "logic")

    @logic.setter
    def logic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logic", value)

    @property
    @pulumi.getter
    def minute(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "minute")

    @minute.setter
    def minute(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "minute", value)

    @property
    @pulumi.getter(name="minuteEnd")
    def minute_end(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "minute_end")

    @minute_end.setter
    def minute_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "minute_end", value)

    @property
    @pulumi.getter
    def month(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "month")

    @month.setter
    def month(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "month", value)

    @property
    @pulumi.getter(name="monthEnd")
    def month_end(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "month_end")

    @month_end.setter
    def month_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "month_end", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="notBefore")
    def not_before(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "not_before")

    @not_before.setter
    def not_before(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "not_before", value)

    @property
    @pulumi.getter(name="notOnOrAfter")
    def not_on_or_after(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "not_on_or_after")

    @not_on_or_after.setter
    def not_on_or_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "not_on_or_after", value)

    @property
    @pulumi.getter
    def year(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "year")

    @year.setter
    def year(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "year", value)

    @property
    @pulumi.getter(name="yearEnd")
    def year_end(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "year_end")

    @year_end.setter
    def year_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "year_end", value)


@pulumi.input_type
class _ClientTimePolicyState:
    def __init__(__self__, *,
                 day_month: Optional[pulumi.Input[str]] = None,
                 day_month_end: Optional[pulumi.Input[str]] = None,
                 decision_strategy: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 hour: Optional[pulumi.Input[str]] = None,
                 hour_end: Optional[pulumi.Input[str]] = None,
                 logic: Optional[pulumi.Input[str]] = None,
                 minute: Optional[pulumi.Input[str]] = None,
                 minute_end: Optional[pulumi.Input[str]] = None,
                 month: Optional[pulumi.Input[str]] = None,
                 month_end: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 not_before: Optional[pulumi.Input[str]] = None,
                 not_on_or_after: Optional[pulumi.Input[str]] = None,
                 realm_id: Optional[pulumi.Input[str]] = None,
                 resource_server_id: Optional[pulumi.Input[str]] = None,
                 year: Optional[pulumi.Input[str]] = None,
                 year_end: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ClientTimePolicy resources.
        """
        if day_month is not None:
            pulumi.set(__self__, "day_month", day_month)
        if day_month_end is not None:
            pulumi.set(__self__, "day_month_end", day_month_end)
        if decision_strategy is not None:
            pulumi.set(__self__, "decision_strategy", decision_strategy)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if hour is not None:
            pulumi.set(__self__, "hour", hour)
        if hour_end is not None:
            pulumi.set(__self__, "hour_end", hour_end)
        if logic is not None:
            pulumi.set(__self__, "logic", logic)
        if minute is not None:
            pulumi.set(__self__, "minute", minute)
        if minute_end is not None:
            pulumi.set(__self__, "minute_end", minute_end)
        if month is not None:
            pulumi.set(__self__, "month", month)
        if month_end is not None:
            pulumi.set(__self__, "month_end", month_end)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if not_before is not None:
            pulumi.set(__self__, "not_before", not_before)
        if not_on_or_after is not None:
            pulumi.set(__self__, "not_on_or_after", not_on_or_after)
        if realm_id is not None:
            pulumi.set(__self__, "realm_id", realm_id)
        if resource_server_id is not None:
            pulumi.set(__self__, "resource_server_id", resource_server_id)
        if year is not None:
            pulumi.set(__self__, "year", year)
        if year_end is not None:
            pulumi.set(__self__, "year_end", year_end)

    @property
    @pulumi.getter(name="dayMonth")
    def day_month(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "day_month")

    @day_month.setter
    def day_month(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "day_month", value)

    @property
    @pulumi.getter(name="dayMonthEnd")
    def day_month_end(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "day_month_end")

    @day_month_end.setter
    def day_month_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "day_month_end", value)

    @property
    @pulumi.getter(name="decisionStrategy")
    def decision_strategy(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "decision_strategy")

    @decision_strategy.setter
    def decision_strategy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "decision_strategy", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def hour(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "hour")

    @hour.setter
    def hour(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hour", value)

    @property
    @pulumi.getter(name="hourEnd")
    def hour_end(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "hour_end")

    @hour_end.setter
    def hour_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hour_end", value)

    @property
    @pulumi.getter
    def logic(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "logic")

    @logic.setter
    def logic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logic", value)

    @property
    @pulumi.getter
    def minute(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "minute")

    @minute.setter
    def minute(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "minute", value)

    @property
    @pulumi.getter(name="minuteEnd")
    def minute_end(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "minute_end")

    @minute_end.setter
    def minute_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "minute_end", value)

    @property
    @pulumi.getter
    def month(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "month")

    @month.setter
    def month(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "month", value)

    @property
    @pulumi.getter(name="monthEnd")
    def month_end(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "month_end")

    @month_end.setter
    def month_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "month_end", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="notBefore")
    def not_before(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "not_before")

    @not_before.setter
    def not_before(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "not_before", value)

    @property
    @pulumi.getter(name="notOnOrAfter")
    def not_on_or_after(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "not_on_or_after")

    @not_on_or_after.setter
    def not_on_or_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "not_on_or_after", value)

    @property
    @pulumi.getter(name="realmId")
    def realm_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "realm_id")

    @realm_id.setter
    def realm_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "realm_id", value)

    @property
    @pulumi.getter(name="resourceServerId")
    def resource_server_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "resource_server_id")

    @resource_server_id.setter
    def resource_server_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_server_id", value)

    @property
    @pulumi.getter
    def year(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "year")

    @year.setter
    def year(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "year", value)

    @property
    @pulumi.getter(name="yearEnd")
    def year_end(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "year_end")

    @year_end.setter
    def year_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "year_end", value)


class ClientTimePolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 day_month: Optional[pulumi.Input[str]] = None,
                 day_month_end: Optional[pulumi.Input[str]] = None,
                 decision_strategy: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 hour: Optional[pulumi.Input[str]] = None,
                 hour_end: Optional[pulumi.Input[str]] = None,
                 logic: Optional[pulumi.Input[str]] = None,
                 minute: Optional[pulumi.Input[str]] = None,
                 minute_end: Optional[pulumi.Input[str]] = None,
                 month: Optional[pulumi.Input[str]] = None,
                 month_end: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 not_before: Optional[pulumi.Input[str]] = None,
                 not_on_or_after: Optional[pulumi.Input[str]] = None,
                 realm_id: Optional[pulumi.Input[str]] = None,
                 resource_server_id: Optional[pulumi.Input[str]] = None,
                 year: Optional[pulumi.Input[str]] = None,
                 year_end: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a ClientTimePolicy resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClientTimePolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a ClientTimePolicy resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param ClientTimePolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClientTimePolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 day_month: Optional[pulumi.Input[str]] = None,
                 day_month_end: Optional[pulumi.Input[str]] = None,
                 decision_strategy: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 hour: Optional[pulumi.Input[str]] = None,
                 hour_end: Optional[pulumi.Input[str]] = None,
                 logic: Optional[pulumi.Input[str]] = None,
                 minute: Optional[pulumi.Input[str]] = None,
                 minute_end: Optional[pulumi.Input[str]] = None,
                 month: Optional[pulumi.Input[str]] = None,
                 month_end: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 not_before: Optional[pulumi.Input[str]] = None,
                 not_on_or_after: Optional[pulumi.Input[str]] = None,
                 realm_id: Optional[pulumi.Input[str]] = None,
                 resource_server_id: Optional[pulumi.Input[str]] = None,
                 year: Optional[pulumi.Input[str]] = None,
                 year_end: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClientTimePolicyArgs.__new__(ClientTimePolicyArgs)

            __props__.__dict__["day_month"] = day_month
            __props__.__dict__["day_month_end"] = day_month_end
            if decision_strategy is None and not opts.urn:
                raise TypeError("Missing required property 'decision_strategy'")
            __props__.__dict__["decision_strategy"] = decision_strategy
            __props__.__dict__["description"] = description
            __props__.__dict__["hour"] = hour
            __props__.__dict__["hour_end"] = hour_end
            __props__.__dict__["logic"] = logic
            __props__.__dict__["minute"] = minute
            __props__.__dict__["minute_end"] = minute_end
            __props__.__dict__["month"] = month
            __props__.__dict__["month_end"] = month_end
            __props__.__dict__["name"] = name
            __props__.__dict__["not_before"] = not_before
            __props__.__dict__["not_on_or_after"] = not_on_or_after
            if realm_id is None and not opts.urn:
                raise TypeError("Missing required property 'realm_id'")
            __props__.__dict__["realm_id"] = realm_id
            if resource_server_id is None and not opts.urn:
                raise TypeError("Missing required property 'resource_server_id'")
            __props__.__dict__["resource_server_id"] = resource_server_id
            __props__.__dict__["year"] = year
            __props__.__dict__["year_end"] = year_end
        super(ClientTimePolicy, __self__).__init__(
            'keycloak:openid/clientTimePolicy:ClientTimePolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            day_month: Optional[pulumi.Input[str]] = None,
            day_month_end: Optional[pulumi.Input[str]] = None,
            decision_strategy: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            hour: Optional[pulumi.Input[str]] = None,
            hour_end: Optional[pulumi.Input[str]] = None,
            logic: Optional[pulumi.Input[str]] = None,
            minute: Optional[pulumi.Input[str]] = None,
            minute_end: Optional[pulumi.Input[str]] = None,
            month: Optional[pulumi.Input[str]] = None,
            month_end: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            not_before: Optional[pulumi.Input[str]] = None,
            not_on_or_after: Optional[pulumi.Input[str]] = None,
            realm_id: Optional[pulumi.Input[str]] = None,
            resource_server_id: Optional[pulumi.Input[str]] = None,
            year: Optional[pulumi.Input[str]] = None,
            year_end: Optional[pulumi.Input[str]] = None) -> 'ClientTimePolicy':
        """
        Get an existing ClientTimePolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClientTimePolicyState.__new__(_ClientTimePolicyState)

        __props__.__dict__["day_month"] = day_month
        __props__.__dict__["day_month_end"] = day_month_end
        __props__.__dict__["decision_strategy"] = decision_strategy
        __props__.__dict__["description"] = description
        __props__.__dict__["hour"] = hour
        __props__.__dict__["hour_end"] = hour_end
        __props__.__dict__["logic"] = logic
        __props__.__dict__["minute"] = minute
        __props__.__dict__["minute_end"] = minute_end
        __props__.__dict__["month"] = month
        __props__.__dict__["month_end"] = month_end
        __props__.__dict__["name"] = name
        __props__.__dict__["not_before"] = not_before
        __props__.__dict__["not_on_or_after"] = not_on_or_after
        __props__.__dict__["realm_id"] = realm_id
        __props__.__dict__["resource_server_id"] = resource_server_id
        __props__.__dict__["year"] = year
        __props__.__dict__["year_end"] = year_end
        return ClientTimePolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dayMonth")
    def day_month(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "day_month")

    @property
    @pulumi.getter(name="dayMonthEnd")
    def day_month_end(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "day_month_end")

    @property
    @pulumi.getter(name="decisionStrategy")
    def decision_strategy(self) -> pulumi.Output[str]:
        return pulumi.get(self, "decision_strategy")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def hour(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "hour")

    @property
    @pulumi.getter(name="hourEnd")
    def hour_end(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "hour_end")

    @property
    @pulumi.getter
    def logic(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "logic")

    @property
    @pulumi.getter
    def minute(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "minute")

    @property
    @pulumi.getter(name="minuteEnd")
    def minute_end(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "minute_end")

    @property
    @pulumi.getter
    def month(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "month")

    @property
    @pulumi.getter(name="monthEnd")
    def month_end(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "month_end")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="notBefore")
    def not_before(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "not_before")

    @property
    @pulumi.getter(name="notOnOrAfter")
    def not_on_or_after(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "not_on_or_after")

    @property
    @pulumi.getter(name="realmId")
    def realm_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "realm_id")

    @property
    @pulumi.getter(name="resourceServerId")
    def resource_server_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "resource_server_id")

    @property
    @pulumi.getter
    def year(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "year")

    @property
    @pulumi.getter(name="yearEnd")
    def year_end(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "year_end")

